@@ -1,7 +1,4 @@
-from typing import Union
-
 from optimade.models import StructureResource
-
 from optimade.adapters.base import EntryAdapter
 
 from .aiida import get_aiida_structure_data
@@ -9,6 +6,7 @@ from .ase import get_ase_atoms
 from .cif import get_cif
 from .proteindatabank import get_pdb, get_pdbx_mmcif
 from .pymatgen import get_pymatgen
+from .jarvis import get_jarvis_atoms
 
 
 __all__ = ("Structure",)
@@ -27,4 +25,5 @@ class Structure(EntryAdapter):
         "pdb": get_pdb,
         "pdbx_mmcif": get_pdbx_mmcif,
         "pymatgen": get_pymatgen,
+        "jarvis": get_jarvis_atoms,
     }
