@@ -15,6 +15,7 @@ from optimade.models import (
     ToplevelLinks,
     ReferenceResource,
     StructureResource,
+    DataType,
 )
 
 from optimade.server.config import CONFIG
@@ -22,16 +23,17 @@ from optimade.server.entry_collections import EntryCollection
 from optimade.server.exceptions import BadRequest
 from optimade.server.query_params import EntryListingQueryParams, SingleEntryQueryParams
 
-
 ENTRY_INFO_SCHEMAS = {
     "structures": StructureResource.schema,
     "references": ReferenceResource.schema,
 }
 
+# we need to get rid of any release tags (e.g. -rc.2) and any build metadata (e.g. +py36)
+# from the api_version before allowing the URL
 BASE_URL_PREFIXES = {
-    "major": f"/v{__api_version__.split('.')[0]}",
-    "minor": f"/v{'.'.join(__api_version__.split('.')[:2])}",
-    "patch": f"/v{__api_version__}",
+    "major": f"/v{__api_version__.split('-')[0].split('+')[0].split('.')[0]}",
+    "minor": f"/v{'.'.join(__api_version__.split('-')[0].split('+')[0].split('.')[:2])}",
+    "patch": f"/v{'.'.join(__api_version__.split('-')[0].split('+')[0].split('.')[:3])}",
 }
 
 
@@ -55,7 +57,7 @@ def meta_values(
 
     return ResponseMeta(
         query=ResponseMetaQuery(representation=f"{url_path}?{parse_result.query}"),
-        api_version=f"v{__api_version__}",
+        api_version=__api_version__,
         time_stamp=datetime.now(),
         data_returned=data_returned,
         more_data_available=more_data_available,
@@ -285,6 +287,10 @@ def retrieve_queryable_properties(schema: dict, queryable_properties: list) -> d
                 # All properties are sortable with the MongoDB backend.
                 # While the result for sorting lists may not be as expected, they are still sorted.
                 properties[name]["sortable"] = True
+                # Try to get OpenAPI-specific "format" if possible, else get "type"; a mandatory OpenAPI key.
+                properties[name]["type"] = DataType.from_json_type(
+                    value.get("format", value["type"])
+                )
     return properties
 
 
@@ -302,15 +308,34 @@ def mongo_id_for_database(database_id: str, database_type: str) -> str:
 
 
 def get_providers():
-    """Retrieve Materials-Consortia providers (from https://providers.optimade.org/providers.json)"""
+    """Retrieve Materials-Consortia providers (from https://providers.optimade.org/v1/links)"""
     import requests
 
-    mat_consortia_providers = requests.get(
-        "https://providers.optimade.org/providers.json"
-    ).json()
+    try:
+        from optimade.server.data import providers
+    except ImportError:
+        providers = None
+
+    if providers is None:
+        try:
+            import simplejson as json
+        except ImportError:
+            import json
+
+        try:
+            providers = requests.get("https://providers.optimade.org/v1/links").json()
+        except (
+            requests.exceptions.ConnectionError,
+            requests.exceptions.ConnectTimeout,
+            json.JSONDecodeError,
+        ):
+            raise BadRequest(
+                status_code=500,
+                detail="Could not retrieve providers list from https://providers.optimade.org",
+            )
 
     providers_list = []
-    for provider in mat_consortia_providers.get("data", []):
+    for provider in providers.get("data", []):
         # Remove/skip "exmpl"
         if provider["id"] == "exmpl":
             continue
